require "import"
import "android.widget.*"
import "android.view.*"
import "android.app.*"
import "android.os.Environment"

local activity = activity
local titleEditText
local contentEditText
local storagePathText

function onCreate(savedInstanceState)
    activity.setTitle("Simple HTML Creator")
    
    local layout = LinearLayout(activity)
    layout.setOrientation(1)
    
    storagePathText = TextView(activity)
    local storagePath = Environment.getExternalStorageDirectory().getAbsolutePath()
    storagePathText.setText("Files will be saved to: " .. storagePath)
    layout.addView(storagePathText)
    
    titleEditText = EditText(activity)
    titleEditText.setHint("Enter page title")
    layout.addView(titleEditText)
    
    contentEditText = EditText(activity)
    contentEditText.setHint("Enter page content")
    contentEditText.setLines(10)
    layout.addView(contentEditText)
    
    local createButton = Button(activity)
    createButton.setText("Create HTML")
    createButton.setOnClickListener{
        onClick = function()
            createHTML()
        end
    }
    layout.addView(createButton)
    
    local howToUseButton = Button(activity)
    howToUseButton.setText("How to Use")
    howToUseButton.setOnClickListener{
        onClick = function()
            showHowToUse()
        end
    }
    layout.addView(howToUseButton)
    
    activity.setContentView(layout)
end

function createHTML()
    local title = titleEditText.getText().toString()
    local content = contentEditText.getText().toString()
    
    if title == "" or content == "" then
        Toast.makeText(activity, "Please enter both title and content", Toast.LENGTH_SHORT).show()
        return
    end
    
    local htmlContent = string.format([[
<!DOCTYPE html>
<html>
<head>
    <title>%s</title>
</head>
<body>
    <h1>%s</h1>
    <p>%s</p>
</body>
</html>
]], title, title, content)
    
    local fileName = title:gsub("%s+", "_") .. ".html"
    local filePath = Environment.getExternalStorageDirectory().getAbsolutePath() .. "/" .. fileName
    
    local file = io.open(filePath, "w")
    if file then
        file:write(htmlContent)
        file:close()
        
        Toast.makeText(activity, "HTML file created: " .. fileName .. "\nStored in: " .. filePath, Toast.LENGTH_LONG).show()
        
        -- Clear input fields after successful file creation
        titleEditText.setText("")
        contentEditText.setText("")
    else
        Toast.makeText(activity, "Error: Unable to create file", Toast.LENGTH_LONG).show()
    end
end

function showHowToUse()
    local howToUseText = [[
How to use Simple HTML Creator:

1. Enter a title for your HTML page in the "Enter page title" field.
2. Type your content in the "Enter page content" field.
3. Click the "Create HTML" button to generate and save the HTML file.
4. The file will be saved in your device's external storage.
5. Use a file manager or web browser to open and view your created HTML file.

Note: Make sure your device has sufficient storage space and the app has permission to write to external storage.
]]

    local builder = AlertDialog.Builder(activity)
    builder.setTitle("How to Use")
    builder.setMessage(howToUseText)
    builder.setPositiveButton("OK", nil)
    local dialog = builder.show()
end